@@ -16,18 +16,18 @@ test_that("lr2 functions match traditional functions", {
     )
 
     expect_equal(
-      propr:::lr2phi(lr),
-      phit(ct, symmetrize = FALSE)@matrix
+      propr:::lr2phi(lr)[1:16],
+      phit(ct, symmetrize = FALSE)@matrix[1:16]
     )
 
     expect_equal(
-      propr:::lr2rho(lr),
-      perb(ct)@matrix
+      propr:::lr2rho(lr)[1:16],
+      perb(ct)@matrix[1:16]
     )
 
     expect_equal(
-      propr:::lr2phs(lr),
-      phis(ct)@matrix
+      propr:::lr2phs(lr)[1:16],
+      phis(ct)@matrix[1:16]
     )
   }
 })
@@ -35,17 +35,17 @@ test_that("lr2 functions match traditional functions", {
 test_that("lr2 functions handle ivar correctly", {
 
   expect_equal(
-    phit(mail, ivar = 2, symmetrize = FALSE)@matrix[, 2],
+    as.vector(phit(mail, ivar = 2, symmetrize = FALSE)@matrix[, 2]),
     c(Inf, 0, Inf, Inf)
   )
 
   expect_equal(
-    perb(mail, ivar = 2)@matrix[, 2],
+    as.vector(perb(mail, ivar = 2)@matrix[, 2]),
     c(0, 1, 0, 0)
   )
 
   expect_equal(
-    phis(mail, ivar = 2)@matrix[, 2],
+    as.vector(phis(mail, ivar = 2)@matrix[, 2]),
     c(Inf, 0, Inf, Inf)
   )
 })
